@@ -1,6 +1,7 @@
 package butlerd
 
 import (
+	"fmt"
 	"time"
 
 	"github.com/itchio/hush"
@@ -1291,6 +1292,30 @@ type CaveInstallInfo struct {
 	Pinned bool `json:"pinned,omitempty"`
 }
 
+// Per-cave launch settings that override global preferences.
+type CaveSettings struct {
+	// Overrides the global sandbox enabled/disabled preference.
+	// nil = inherit global, true = force on, false = force off
+	// @optional
+	Sandbox *bool `json:"sandbox,omitempty"`
+
+	// Override sandbox runner type (bubblewrap, firejail, flatpak, fuji, auto).
+	// @optional
+	SandboxType *SandboxType `json:"sandboxType,omitempty"`
+
+	// Override network restriction within the sandbox.
+	// @optional
+	SandboxNoNetwork *bool `json:"sandboxNoNetwork,omitempty"`
+
+	// Override allowed environment variables within the sandbox.
+	// @optional
+	SandboxAllowEnv *[]string `json:"sandboxAllowEnv,omitempty"`
+
+	// Additional command-line arguments appended after manifest action args.
+	// @optional
+	ExtraArgs []string `json:"extraArgs,omitempty"`
+}
+
 type InstallLocationSummary struct {
 	// Unique identifier for this install location
 	ID string `json:"id"`
@@ -1526,19 +1551,15 @@ type InstallQueueResult struct {
 	InstallLocationID string         `json:"installLocationId"`
 }
 
-// For modal-first install
+// @deprecated Install.Plan can take a long time calculating space requirements and can't be canceled. Use Install.GetUploads to quickly list available uploads, then Install.PlanUpload to calculate extraction details for a specific upload (with cancellation support).
 //
 // @name Install.Plan
 // @category Install
 // @caller client
 type InstallPlanParams struct {
-	// The ID of the game we're planning to install
 	GameID int64 `json:"gameId"`
-
-	// The download session ID to use for this install plan
 	// @optional
 	DownloadSessionID string `json:"downloadSessionId"`
-
 	// @optional
 	UploadID int64 `json:"uploadId"`
 }
@@ -1552,7 +1573,53 @@ func (p InstallPlanParams) Validate() error {
 type InstallPlanResult struct {
 	Game    *itchio.Game     `json:"game"`
 	Uploads []*itchio.Upload `json:"uploads"`
+	Info    *InstallPlanInfo `json:"info"`
+}
 
+// Returns the list of available uploads for a game, narrowed by platform/format.
+// This is the fast part of install planning (no file I/O).
+//
+// @name Install.GetUploads
+// @category Install
+// @caller client
+type InstallGetUploadsParams struct {
+	GameID int64 `json:"gameId"`
+}
+
+func (p InstallGetUploadsParams) Validate() error {
+	return validation.ValidateStruct(&p,
+		validation.Field(&p.GameID, validation.Required),
+	)
+}
+
+type InstallGetUploadsResult struct {
+	Game    *itchio.Game     `json:"game"`
+	Uploads []*itchio.Upload `json:"uploads"`
+}
+
+// Returns installer type and disk usage info for a specific upload.
+// This is the slow part of install planning (network I/O + file inspection).
+//
+// @name Install.PlanUpload
+// @category Install
+// @caller client
+type InstallPlanUploadParams struct {
+	// ID for cancellation support. If provided, can be cancelled via Install.Cancel
+	// @optional
+	ID string `json:"id"`
+
+	UploadID int64 `json:"uploadId"`
+	// @optional
+	DownloadSessionID string `json:"downloadSessionId"`
+}
+
+func (p InstallPlanUploadParams) Validate() error {
+	return validation.ValidateStruct(&p,
+		validation.Field(&p.UploadID, validation.Required),
+	)
+}
+
+type InstallPlanUploadResult struct {
 	Info *InstallPlanInfo `json:"info"`
 }
 
@@ -1573,6 +1640,49 @@ type DiskUsageInfo struct {
 	Accuracy        string `json:"accuracy"`
 }
 
+// @name Caves.GetSettings
+// @category Install
+// @caller client
+type CavesGetSettingsParams struct {
+	// ID of the cave to retrieve settings for.
+	CaveID string `json:"caveId"`
+}
+
+func (p CavesGetSettingsParams) Validate() error {
+	return validation.ValidateStruct(&p,
+		validation.Field(&p.CaveID, validation.Required),
+	)
+}
+
+type CavesGetSettingsResult struct {
+	Settings CaveSettings `json:"settings"`
+}
+
+// @name Caves.SetSettings
+// @category Install
+// @caller client
+type CavesSetSettingsParams struct {
+	// ID of the cave to store settings for.
+	CaveID string `json:"caveId"`
+
+	// Full settings object replacement.
+	Settings *CaveSettings `json:"settings"`
+}
+
+func (p CavesSetSettingsParams) Validate() error {
+	err := validation.ValidateStruct(&p,
+		validation.Field(&p.CaveID, validation.Required),
+		validation.Field(&p.Settings, validation.Required),
+	)
+	if err != nil {
+		return err
+	}
+
+	return validateCaveSettings(p.Settings)
+}
+
+type CavesSetSettingsResult struct{}
+
 // @name Caves.SetPinned
 // @category Install
 // @caller client
@@ -2308,13 +2418,77 @@ type LaunchParams struct {
 	// Enable sandbox (regardless of manifest opt-in)
 	// @optional
 	Sandbox bool `json:"sandbox,omitempty"`
+
+	// Sandbox configuration options. Only applied when sandbox is enabled.
+	// @optional
+	SandboxOptions *SandboxOptions `json:"sandboxOptions,omitempty"`
+
+	// Additional command-line arguments appended after manifest action args.
+	// @optional
+	ExtraArgs []string `json:"extraArgs,omitempty"`
+}
+
+type SandboxType string
+
+const (
+	SandboxTypeAuto       SandboxType = "auto"
+	SandboxTypeBubblewrap SandboxType = "bubblewrap"
+	SandboxTypeFirejail   SandboxType = "firejail"
+	SandboxTypeFlatpak    SandboxType = "flatpak"
+	SandboxTypeFuji       SandboxType = "fuji"
+)
+
+var SandboxTypeList = []interface{}{
+	SandboxTypeAuto,
+	SandboxTypeBubblewrap,
+	SandboxTypeFirejail,
+	SandboxTypeFlatpak,
+	SandboxTypeFuji,
+}
+
+// Options for controlling sandbox behavior.
+type SandboxOptions struct {
+	// Which sandbox runner to use. Empty string means auto-detect.
+	// @optional
+	Type SandboxType `json:"type,omitempty"`
+
+	// (Linux Only) If true, disable network access within the sandbox.
+	// @optional
+	NoNetwork bool `json:"noNetwork,omitempty"`
+
+	// (Linux Only) List of environment variable names to allow through from the host into the sandbox.
+	// @optional
+	AllowEnv []string `json:"allowEnv,omitempty"`
+}
+
+func validateCaveSettings(settings *CaveSettings) error {
+	if settings == nil || settings.SandboxType == nil || *settings.SandboxType == "" {
+		return nil
+	}
+
+	err := validation.Validate(*settings.SandboxType, validation.In(SandboxTypeList...))
+	if err != nil {
+		return fmt.Errorf("settings.sandboxType: %w", err)
+	}
+
+	return nil
 }
 
 func (p LaunchParams) Validate() error {
-	return validation.ValidateStruct(&p,
+	err := validation.ValidateStruct(&p,
 		validation.Field(&p.CaveID, validation.Required),
 		validation.Field(&p.PrereqsDir, validation.Required),
 	)
+	if err != nil {
+		return err
+	}
+	if p.SandboxOptions != nil && p.SandboxOptions.Type != "" {
+		err = validation.Validate(p.SandboxOptions.Type, validation.In(SandboxTypeList...))
+		if err != nil {
+			return fmt.Errorf("sandboxOptions.type: %w", err)
+		}
+	}
+	return nil
 }
 
 type LaunchResult struct {
