@@ -8,6 +8,8 @@ import (
 func Register(router *butlerd.Router) {
 	messages.GameFindUploads.Register(router, GameFindUploads)
 	messages.InstallPlan.Register(router, InstallPlan)
+	messages.InstallGetUploads.Register(router, InstallGetUploads)
+	messages.InstallPlanUpload.Register(router, InstallPlanUpload)
 	messages.InstallQueue.Register(router, InstallQueue)
 	messages.InstallPerform.Register(router, InstallPerform)
 	messages.InstallCancel.Register(router, InstallCancel)
@@ -20,5 +22,7 @@ func Register(router *butlerd.Router) {
 	messages.InstallLocationsScan.Register(router, InstallLocationsScan)
 	messages.InstallCreateShortcut.Register(router, InstallCreateShortcut)
 
+	messages.CavesGetSettings.Register(router, CavesGetSettings)
+	messages.CavesSetSettings.Register(router, CavesSetSettings)
 	messages.CavesSetPinned.Register(router, CavesSetPinned)
 }
