@@ -1,8 +1,6 @@
 package install
 
 import (
-	"context"
-
 	"github.com/itchio/butler/butlerd"
 	"github.com/itchio/butler/cmd/operate"
 	"github.com/pkg/errors"
@@ -13,11 +11,8 @@ func InstallPerform(rc *butlerd.RequestContext, params butlerd.InstallPerformPar
 		return nil, errors.New("Missing ID")
 	}
 
-	parentCtx := rc.Ctx
-	ctx, cancelFunc := context.WithCancel(parentCtx)
-
-	rc.CancelFuncs.Add(params.ID, cancelFunc)
-	defer rc.CancelFuncs.Remove(params.ID)
+	ctx, cleanup := rc.MakeCancelable(params.ID)
+	defer cleanup()
 
 	res, err := operate.InstallPerform(ctx, rc, params)
 	if err != nil {
