@@ -190,12 +190,26 @@ func (l *Launcher) Do(params launch.LauncherParams) error {
 		consumer.Infof("Console launch requested")
 	}
 
+	var sandboxConfig runner.SandboxConfig
+	if params.SandboxOptions != nil {
+		sandboxType := runner.SandboxType(string(params.SandboxOptions.Type))
+		if params.SandboxOptions.Type == butlerd.SandboxTypeAuto || params.SandboxOptions.Type == "" {
+			sandboxType = runner.SandboxTypeAuto
+		}
+		sandboxConfig = runner.SandboxConfig{
+			Type:      sandboxType,
+			NoNetwork: params.SandboxOptions.NoNetwork,
+			AllowEnv:  params.SandboxOptions.AllowEnv,
+		}
+	}
+
 	runParams := runner.RunnerParams{
 		Consumer: consumer,
 		Ctx:      params.Ctx,
 
-		Sandbox: params.Sandbox,
-		Console: console,
+		Sandbox:       params.Sandbox,
+		SandboxConfig: sandboxConfig,
+		Console:       console,
 
 		FullTargetPath: fullTargetPath,
 
@@ -210,9 +224,11 @@ func (l *Launcher) Do(params launch.LauncherParams) error {
 		InstallFolder: params.InstallFolder,
 		Runtime:       params.Host.Runtime,
 
-		AttachParams:   l.AttachParams(params),
-		FirejailParams: l.FirejailParams(params),
-		FujiParams:     l.FujiParams(params),
+		AttachParams:       l.AttachParams(params),
+		FirejailParams:     l.FirejailParams(params),
+		BubblewrapParams:   l.BubblewrapParams(params),
+		FlatpakSpawnParams: l.FlatpakSpawnParams(params),
+		FujiParams:         l.FujiParams(params),
 	}
 
 	run, err := runner.GetRunner(runParams)
@@ -293,11 +309,26 @@ func (l *Launcher) Do(params launch.LauncherParams) error {
 }
 
 func (l *Launcher) FirejailParams(params launch.LauncherParams) runner.FirejailParams {
+	// Prefer system-installed firejail
+	if systemPath, err := exec.LookPath("firejail"); err == nil {
+		return runner.FirejailParams{BinaryPath: systemPath}
+	}
+
+	// Fall back to prereqs-installed firejail
 	name := fmt.Sprintf("firejail-%s", params.Host.Runtime.Arch())
 	binaryPath := filepath.Join(params.PrereqsDir, name, "firejail")
-	return runner.FirejailParams{
-		BinaryPath: binaryPath,
+	return runner.FirejailParams{BinaryPath: binaryPath}
+}
+
+func (l *Launcher) BubblewrapParams(params launch.LauncherParams) runner.BubblewrapParams {
+	if bwrapPath, err := exec.LookPath("bwrap"); err == nil {
+		return runner.BubblewrapParams{BinaryPath: bwrapPath}
 	}
+	return runner.BubblewrapParams{}
+}
+
+func (l *Launcher) FlatpakSpawnParams(params launch.LauncherParams) runner.FlatpakSpawnParams {
+	return runner.FlatpakSpawnParams{}
 }
 
 func (l *Launcher) FujiParams(params launch.LauncherParams) runner.FujiParams {
