@@ -12,6 +12,5 @@ func init() {
 	// it. If you remove this, windows sandboxing will break.
 	// No, I don't know either. It seems a Windows 2012 update
 	// broke this.
-	C.IsWindow(C.HWND(nil));
+	C.IsWindow(C.HWND(nil))
 }
-
